pub struct SyncConfig {
pub enable: Option<bool>,
pub dir: Option<PathBuf>,
pub strategy: Option<FolderSyncStrategy>,
}Fields
enable: Option<bool>Enable the synchronization of the current account with local Maildir backend features.
dir: Option<PathBuf>Customize the root directory where the Maildir cache is saved.
Defaults to $XDG_DATA_HOME/himalaya/<account-name>.
strategy: Option<FolderSyncStrategy>👎Deprecated since 0.22.0: use FolderConfig::sync::filter instead