BackendContext

Trait BackendContext 

pub trait BackendContext: Send + Sync { }
The backend context.

This is just a marker for other backend traits. Every backend context needs to implement this trait manually or to derive [crate::backend_v2::macros::BackendContextV2].

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors