pub trait CheckUp: Send + Sync {
// Provided method
fn check_up<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = AnyResult<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
}Expand description
Backend builder feature for checking up configuration and context integrity.
This feature is used to check the integrity of the context.
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".