Struct email::email::config::EmailHooks
source · pub struct EmailHooks {
pub pre_send: Option<Command>,
}Expand description
The email hooks configuration.
Represents the email hooks configuration. They can be useful for doing post and pre processing.
Fields
pre_send: Option<Command>The hook called just before sending an email. The system command should take the raw message as a unique parameter and returns the modified raw message.
Implementations