EmailSyncCacheHunk

Enum EmailSyncCacheHunk 

pub enum EmailSyncCacheHunk {
    Insert(FolderName, Envelope, SyncDestination),
    Delete(FolderName, Id, SyncDestination),
}
The email synchronization cache hunk.

Similar to the EmailSyncHunk, except that this hunk is specific to the cache (SQLite).

Variants



Insert(FolderName, Envelope, SyncDestination)

The email matching the given envelope identifier needs to be added to the cache for the given destination.



Delete(FolderName, Id, SyncDestination)

The email matching the given identifier needs to be removed from the cache for the given destination.