pub struct EnvelopeSyncFilters {
pub before: Option<DateTime<Local>>,
pub after: Option<DateTime<Local>>,
}Fields
before: Option<DateTime<Local>>Filter envelopes with a Date header more recent than the given
date.
after: Option<DateTime<Local>>Filter envelopes with a Date header older than the given date.
Implementations
sourceimpl EnvelopeSyncFilters
impl EnvelopeSyncFilters
pub fn set_some_after(&mut self, date: Option<impl Into<DateTime<Local>>>)
pub fn set_after(&mut self, date: impl Into<DateTime<Local>>)
pub fn with_some_after(self, date: Option<impl Into<DateTime<Local>>>) -> Self
pub fn with_after(self, date: impl Into<DateTime<Local>>) -> Self
pub fn after(&self) -> Option<&DateTime<Local>>
pub fn set_some_before(&mut self, date: Option<impl Into<DateTime<Local>>>)
pub fn set_before(&mut self, date: impl Into<DateTime<Local>>)
pub fn with_some_before(self, date: Option<impl Into<DateTime<Local>>>) -> Self
pub fn with_before(self, date: impl Into<DateTime<Local>>) -> Self
pub fn before(&self) -> Option<&DateTime<Local>>
pub fn matches(&self, envelope: &Envelope) -> bool
pub fn matches_after(&self, date: &DateTime<Local>) -> bool
pub fn matches_before(&self, date: &DateTime<Local>) -> bool