Module thread

Module thread 

Modules

config
imap
maildir

Traits

ThreadEnvelopes

Functions

build_thread_graph_all
Build a thread graph from envelopes using In-Reply-To / Message-ID relationships. This is a client-side threading algorithm that works regardless of whether the server supports IMAP THREAD.
build_thread_graph_for_id
Build a thread graph filtered to only the thread containing the given envelope ID.