pub fn build_thread_graph_for_id<'a>(
envelopes: &'a HashMap<String, Envelope>,
id: &str,
) -> DiGraphMap<ThreadedEnvelope<'a>, u8>Expand description
Build a thread graph filtered to only the thread containing the given envelope ID.
pub fn build_thread_graph_for_id<'a>(
envelopes: &'a HashMap<String, Envelope>,
id: &str,
) -> DiGraphMap<ThreadedEnvelope<'a>, u8>Build a thread graph filtered to only the thread containing the given envelope ID.