SetFlags

Trait SetFlags 

pub trait SetFlags: Send + Sync {
    // Required method
    fn set_flags<'life0, 'life1, 'life2, 'life3, 'async_trait>(
        &'life0 self,
        folder: &'life1 str,
        id: &'life2 Id,
        flags: &'life3 Flags,
    ) -> Pin<Box<dyn Future<Output = AnyResult<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait,
             'life3: 'async_trait;

    // Provided method
    fn set_flag<'life0, 'life1, 'life2, 'async_trait>(
        &'life0 self,
        folder: &'life1 str,
        id: &'life2 Id,
        flag: Flag,
    ) -> Pin<Box<dyn Future<Output = AnyResult<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait { ... }
}

Required Methods

fn set_flags<'life0, 'life1, 'life2, 'life3, 'async_trait>( &'life0 self, folder: &'life1 str, id: &'life2 Id, flags: &'life3 Flags, ) -> Pin<Box<dyn Future<Output = AnyResult<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait, 'life3: 'async_trait,

Set the given flags to envelope(s) matching the given id from the given folder.

This function replaces any exsting flags by the given ones.

Provided Methods

fn set_flag<'life0, 'life1, 'life2, 'async_trait>( &'life0 self, folder: &'life1 str, id: &'life2 Id, flag: Flag, ) -> Pin<Box<dyn Future<Output = AnyResult<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait,

Set the given flag to envelope(s) matching the given id from the given folder.

This function replaces any exsting flags by the given one.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors