Folder module
Module dedicated to folder (as known as mailbox) management.
The main entities are FolderKind, Folder and Folders.
The config module exposes all the folder configuration used by
the account configuration.
Backend features reside in their own module as well: add,
list, expunge, purge, delete.
Finally, the sync module contains everything needed to
synchronize a remote folder with a local one.
Modules
- Module dedicated to Maildir email folders.
- Module dedicated to folders synchronization.
Structs
- The folder structure.
- The list of folders.
Enums
- Errors dedicated to folder management.
- The folder kind enumeration.