Module email::folder::sync

source ·
Module dedicated to folders synchronization.

This module contains everything you need to synchronize remote folders with local ones.

Modules

  • Module dedicated to email folders synchronization cache.

Structs

Enums

Type Aliases

  • Alias for the folder name.
  • A folder synchronization cache patch is just a list of folder synchronization cache hunks (changes).
  • A folder synchronization patch is just a list of folder synchronization hunks (changes).
  • A folder synchronization patches associates a folder with its own patch.
  • Alias for the unique set of folder names.