Enum email::folder::sync::FolderSyncCacheHunk
source · pub enum FolderSyncCacheHunk {
Insert(FolderName, Target),
Delete(FolderName, Target),
}Expand description
The folder synchronization cache hunk.
Similar to the FolderSyncHunk, except that this hunk is
specific to the cache (SQLite).
Variants
Insert(FolderName, Target)
The given folder name needs to be added to the cache for the given destination.
Delete(FolderName, Target)
The given folder name needs to be removed from the cache for the given destination.