Enum email::folder::sync::FolderSyncHunk
source · pub enum FolderSyncHunk {
Create(FolderName, Target),
Cache(FolderName, Target),
Delete(FolderName, Target),
Uncache(FolderName, Target),
}Expand description
The folder synchronization hunk.
Variants
Create(FolderName, Target)
The given folder name needs to be created to the given destination.
Cache(FolderName, Target)
The given folder name needs to be added to the cache for the given destination.
Delete(FolderName, Target)
The given folder needs to be deleted from the given destination.
Uncache(FolderName, Target)
The given folder needs to be removed from the cache for the given destination.
Implementations