pub type FolderSyncPatch = BTreeSet<FolderSyncHunk>;Expand description
A folder synchronization patch is just a list of folder synchronization hunks (changes).
Aliased Type
pub struct FolderSyncPatch { /* private fields */ }pub type FolderSyncPatch = BTreeSet<FolderSyncHunk>;A folder synchronization patch is just a list of folder synchronization hunks (changes).
pub struct FolderSyncPatch { /* private fields */ }