pub type FolderSyncPatches = BTreeMap<FolderName, FolderSyncPatch>;Expand description
A folder synchronization patches associates a folder with its own patch.
Aliased Type
pub struct FolderSyncPatches { /* private fields */ }pub type FolderSyncPatches = BTreeMap<FolderName, FolderSyncPatch>;A folder synchronization patches associates a folder with its own patch.
pub struct FolderSyncPatches { /* private fields */ }