Module dedicated to email folders synchronization reporting.
The core structure of this module is the FolderSyncReport.
Structs
- The folder synchronization report.
Module dedicated to email folders synchronization reporting.
The core structure of this module is the FolderSyncReport.