pub struct FolderSyncReport {
pub names: FoldersName,
pub patch: Vec<(FolderSyncHunk, Option<AnyBoxedError>)>,
}Expand description
The folder synchronization report.
Fields
names: FoldersNameThe list of folders found during the synchronization process.
patch: Vec<(FolderSyncHunk, Option<AnyBoxedError>)>The list of processed hunks associated with an optional error. Hunks that could not be processed are ignored.