Struct email::folder::sync::FolderSyncReport
source · pub struct FolderSyncReport {
pub folders: FoldersName,
pub patch: Vec<(FolderSyncHunk, Option<Error>)>,
pub cache_patch: (Vec<FolderSyncCacheHunk>, Option<Error>),
}Expand description
The folder synchronization report.
Fields
folders: FoldersNameThe list of folders found during the synchronization process.
patch: Vec<(FolderSyncHunk, Option<Error>)>The list of processed hunks associated with an optional error. Hunks that could not be processed are ignored.
cache_patch: (Vec<FolderSyncCacheHunk>, Option<Error>)The list of processed cache hunks associated with an optional error. Cache hunks that could not be processed are ignored.