pub struct ImapConfig {
pub host: String,
pub port: u16,
pub encryption: Option<Encryption>,
pub login: String,
pub auth: ImapAuthConfig,
pub extensions: Option<ImapExtensionsConfig>,
pub watch: Option<ImapWatchConfig>,
pub clients_pool_size: Option<u8>,
}Expand description
Errors related to the IMAP backend configuration. The IMAP backend configuration.
Fields
host: StringThe IMAP server host name.
port: u16The IMAP server host port.
encryption: Option<Encryption>The IMAP encryption protocol to use.
Supported encryption: SSL/TLS, STARTTLS or none.
login: StringThe IMAP server login.
Usually, the login is either the email address or its left part (before @).
auth: ImapAuthConfigThe IMAP server authentication configuration.
Authentication can be done using password or OAuth 2.0. See ImapAuthConfig.
extensions: Option<ImapExtensionsConfig>The IMAP extensions configuration.
watch: Option<ImapWatchConfig>The IMAP notify command.
Defines the command used to notify the user when a new email is available.
Defaults to notify-send "📫 <sender>" "<subject>".
clients_pool_size: Option<u8>The IMAP clients pool size.
Defines the number of clients that are created and managed simultaneously by the IMAP context. Defaults to 1.
Implementations
Sourceimpl ImapConfig
impl ImapConfig
pub fn clients_pool_size(&self) -> u8
pub fn send_id_after_auth(&self) -> bool
Sourcepub fn is_encryption_enabled(&self) -> bool
pub fn is_encryption_enabled(&self) -> bool
Return true if TLS or StartTLS is enabled.
Sourcepub fn is_start_tls_encryption_enabled(&self) -> bool
pub fn is_start_tls_encryption_enabled(&self) -> bool
Return true if StartTLS is enabled.
Sourcepub fn is_encryption_disabled(&self) -> bool
pub fn is_encryption_disabled(&self) -> bool
Return true if encryption is disabled.
Sourcepub async fn build_credentials(&self) -> Result<String>
pub async fn build_credentials(&self) -> Result<String>
Builds authentication credentials.
Authentication credentials can be either a password or an OAuth 2.0 access token.
Sourcepub fn find_watch_timeout(&self) -> Option<u64>
pub fn find_watch_timeout(&self) -> Option<u64>
Find the IMAP watch timeout.