GetMessages

Trait GetMessages 

pub trait GetMessages: Send + Sync {
    // Required method
    fn get_messages<'life0, 'life1, 'life2, 'async_trait>(
        &'life0 self,
        folder: &'life1 str,
        id: &'life2 Id,
    ) -> Pin<Box<dyn Future<Output = AnyResult<Messages>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait;
}
Get messages feature.

Required Methods

fn get_messages<'life0, 'life1, 'life2, 'async_trait>( &'life0 self, folder: &'life1 str, id: &'life2 Id, ) -> Pin<Box<dyn Future<Output = AnyResult<Messages>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait,

Get email messages from the given folder matching the given ids.

When getting messages, the Flag::Seen is added to the associated envelopes. If you do not want envelopes to change, see PeekMessages.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors