Module reply

Module reply 

Reply template

The main structure of this module is the ReplyTemplateBuilder, which helps you to build template in order to reply to a message.

Modules

config

Structs

ReplyTemplateBuilder
The message reply template builder.