SmtpContextSync

Type Alias SmtpContextSync 

pub type SmtpContextSync = Arc<Mutex<SmtpContext>>;
The sync version of the SMTP backend context.

This is just an SMTP client wrapped into a mutex, so the same SMTP client can be shared and updated across multiple threads.

Aliased Type

pub struct SmtpContextSync { /* private fields */ }