Module forward

Module forward 

Forward template

The main structure of this module is the ForwardTemplateBuilder, which helps you to build template in order to forward a message.

Modules

config

Structs

ForwardTemplateBuilder
The message reply template builder.