AnyError

Trait AnyError 

pub trait AnyError:
    Error
    + Any
    + Send
    + Sync {
    // Required method
    fn as_any(&self) -> &dyn Any;
}
The global, dowcastable any Error trait of the library.

This trait is used instead of [Error] when an error that is not known at compilation time cannot be placed in a generic due to object-safe trait constraint. The main use case is for backend features.

Required Methods

fn as_any(&self) -> &dyn Any

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl AnyError for JoinError

Source

fn as_any(&self) -> &dyn Any

Implementors

Source

impl AnyError for email::backend::Error

Source

impl AnyError for email::Error

Source

impl AnyError for email::folder::Error

Source

impl AnyError for email::imap::Error

Source

impl AnyError for email::maildir::Error

Source

impl AnyError for email::sendmail::Error

Source

impl AnyError for email::smtp::Error