pub struct WatchHook {
pub cmd: Option<Command>,
pub notify: Option<WatchNotifyConfig>,
pub callback: Option<WatchFn>,
}Expand description
Watch hook configuration.
Each variant represent the action that should be done when a change occurs.
Fields
cmd: Option<Command>Execute the shell command.
For now, command is executed without any parameter nor input. This may change in the future.
notify: Option<WatchNotifyConfig>Send a system notification using the given
notify_rust::Notification-like configuration.
callback: Option<WatchFn>Execute the given watch function.
The watch function cannot be de/serialized. The function
should take a reference to an envelope and return a Result
of unit.