pub struct AccountConfig {
Show 20 fields pub name: String, pub email: String, pub display_name: Option<String>, pub signature_delim: Option<String>, pub signature: Option<String>, pub downloads_dir: Option<PathBuf>, pub folder_listing_page_size: Option<usize>, pub folder_aliases: HashMap<String, String>, pub email_listing_page_size: Option<usize>, pub email_listing_datetime_fmt: Option<String>, pub email_listing_datetime_local_tz: Option<bool>, pub email_reading_headers: Option<Vec<String>>, pub email_reading_format: EmailTextPlainFormat, pub email_writing_headers: Option<Vec<String>>, pub email_sending_save_copy: Option<bool>, pub email_hooks: EmailHooks, pub sync: bool, pub sync_dir: Option<PathBuf>, pub sync_folders_strategy: FolderSyncStrategy, pub pgp: Option<PgpConfig>,
}
The user’s account configuration.

It represents everything that the user can customize for a given account. It is the main configuration used by all other modules. Usually, it serves as a reference for building config file structure.

Fields

name: String

The name of the user account. It serves as an unique identifier for a given configuration.

email: String

The email address of the user account.

display_name: Option<String>

The display name of the user. It usually corresponds to the full name of the user.

signature_delim: Option<String>

The email signature delimiter of the user signature. Defaults to -- \n.

signature: Option<String>

Represents the email signature of the user. It can be either a path to a file (usually ~/.signature) or a raw string.

downloads_dir: Option<PathBuf>

Represents the downloads directory. It is used for downloading attachments.

folder_listing_page_size: Option<usize>

Represents the page size when listing folders. A page size of 0 disables the pagination and shows all available folders.

folder_aliases: HashMap<String, String>

Represents the folder aliases hash map. There is 4 special aliases:

  • inbox: main folder containing incoming emails
  • draft(s): folder containing draft emails
  • sent: folder containing emails sent
  • trash: folder containing trashed emails
email_listing_page_size: Option<usize>

Represents the page size when listing envelopes. A page size of 0 disables the pagination and shows all available envelopes.

email_listing_datetime_fmt: Option<String>

Custom format for displaying envelopes date. See chrono::format::strftime for supported formats. Defaults to %F %R%:z.

email_listing_datetime_local_tz: Option<bool>

If true, transform envelopes date timezone into the user’s local one. For example, if the user’s local timezone is UTC, the envelope date 2023-06-15T09:00:00+02:00 becomes 2023-06-15T07:00:00-00:00.

email_reading_headers: Option<Vec<String>>

Represents headers visible at the top of email messages when reading them.

email_reading_format: EmailTextPlainFormat

Represents the text/plain format as defined in the RFC 2646.

email_writing_headers: Option<Vec<String>>

Represents headers visible at the top of emails when writing them (new/reply/forward).

email_sending_save_copy: Option<bool>

Should save a copy of the email being sent in the sent folder. The sent folder can be customized using folder_aliases. Knowing that 1) saving an email is done by the Backend, 2) sending an email is done by the Sender, and 3) both have no relation together, it is the library user’s responsibility to check this option and to save the copy of the sent email.

AccountConfig {
    folder_aliases: HashMap::from_iter([("sent", "MyCustomSent")]),
    email_sending_save_copy: true,
    ..Default::default()
};
email_hooks: EmailHooks

Represents the email hooks.

sync: bool

Enables the synchronization of this account with a local Maildir backend.

sync_dir: Option<PathBuf>

Custom root directory where the Maildir cache is saved. Defaults to $XDG_DATA_HOME/himalaya/<account-name>.

sync_folders_strategy: FolderSyncStrategy

Represents the synchronization strategy to use for folders.

pgp: Option<PgpConfig>

The configuration related to PGP encryption.

Implementations

source

impl AccountConfig

source

pub fn from(&self) -> Address<'_>

Build a mail_builder::headers::address from a user account configuration. This is mostly used for building the From header by message builders.

source

pub fn downloads_dir(&self) -> PathBuf

Expand the downloads directory path. Falls back to temporary directory.

source

pub fn download_fpath(&self, fname: impl AsRef<str>) -> Result<PathBuf>

Wrapper around downloads_dir() and rename_file_if_duplicate().

source

pub fn find_folder_alias(&self, folder: &str) -> Result<Option<String>>

Return the alias of the given folder if defined, otherwise return None.

source

pub fn get_folder_alias(&self, folder: &str) -> Result<String>

Return the alias of the given folder if defined, otherwise return the folder itself. Then expand shell variables.

source

pub fn inbox_folder_alias(&self) -> Result<String>

Return the inbox folder alias.

source

pub fn drafts_folder_alias(&self) -> Result<String>

Return the drafts folder alias.

source

pub fn sent_folder_alias(&self) -> Result<String>

Return the sent folder alias.

source

pub fn trash_folder_alias(&self) -> Result<String>

Return the trash folder alias.

source

pub fn email_listing_page_size(&self) -> usize

Return the email listing page size if defined, otherwise return the default one.

source

pub fn email_reading_headers(&self) -> Vec<String>

Return the email reading headers if defined, otherwise return the default ones.

source

pub fn email_writing_headers(&self) -> Vec<String>

Return the email writing headers if defined, otherwise return the default ones.

source

pub fn signature(&self) -> Result<Option<String>>

Return the full signature, including the delimiter.

source

pub fn sync_dir_exists(&self) -> bool

Return true if the sync directory already exists.

source

pub fn sync(&self) -> bool

Return true if the sync directory already exists and if the sync feature is enabled.

source

pub fn sync_dir(&self) -> Result<PathBuf>

Return the sync directory if exist, otherwise create it.

source

pub fn sync_db_builder(&self) -> Result<Connection>

Open a SQLite connection to the synchronization database.

source

pub fn generate_tpl_interpreter(&self) -> MimeInterpreterBuilder

Generate a template interpreter with prefilled options from the current user account configuration.

source

pub fn email_listing_datetime_fmt(&self) -> String

Return the email listing datetime format, otherwise return the default one.

source

pub fn email_listing_datetime_local_tz(&self) -> bool

Return the email listing datetime local timezone option, otherwise return the default one.