Struct email::backend::pool::BackendPool
source · pub struct BackendPool<C: BackendContext> {Show 20 fields
pub account_config: Arc<AccountConfig>,
pub pool: ThreadPool<C>,
pub add_folder: Option<BackendFeature<C, dyn AddFolder>>,
pub list_folders: Option<BackendFeature<C, dyn ListFolders>>,
pub expunge_folder: Option<BackendFeature<C, dyn ExpungeFolder>>,
pub purge_folder: Option<BackendFeature<C, dyn PurgeFolder>>,
pub delete_folder: Option<BackendFeature<C, dyn DeleteFolder>>,
pub get_envelope: Option<BackendFeature<C, dyn GetEnvelope>>,
pub list_envelopes: Option<BackendFeature<C, dyn ListEnvelopes>>,
pub watch_envelopes: Option<BackendFeature<C, dyn WatchEnvelopes>>,
pub add_flags: Option<BackendFeature<C, dyn AddFlags>>,
pub set_flags: Option<BackendFeature<C, dyn SetFlags>>,
pub remove_flags: Option<BackendFeature<C, dyn RemoveFlags>>,
pub add_message: Option<BackendFeature<C, dyn AddMessage>>,
pub send_message: Option<BackendFeature<C, dyn SendMessage>>,
pub peek_messages: Option<BackendFeature<C, dyn PeekMessages>>,
pub get_messages: Option<BackendFeature<C, dyn GetMessages>>,
pub copy_messages: Option<BackendFeature<C, dyn CopyMessages>>,
pub move_messages: Option<BackendFeature<C, dyn MoveMessages>>,
pub delete_messages: Option<BackendFeature<C, dyn DeleteMessages>>,
}Expand description
The backend pool.
This implementation owns a pool of context, and backend features are executed by the first available context.
This implementation is useful when you need to call a batch of features, in parallel.
Fields
account_config: Arc<AccountConfig>The account configuration.
pool: ThreadPool<C>The backend context pool.
add_folder: Option<BackendFeature<C, dyn AddFolder>>The add folder backend feature.
list_folders: Option<BackendFeature<C, dyn ListFolders>>The list folders backend feature.
expunge_folder: Option<BackendFeature<C, dyn ExpungeFolder>>The expunge folder backend feature.
purge_folder: Option<BackendFeature<C, dyn PurgeFolder>>The purge folder backend feature.
delete_folder: Option<BackendFeature<C, dyn DeleteFolder>>The delete folder backend feature.
get_envelope: Option<BackendFeature<C, dyn GetEnvelope>>The get envelope backend feature.
list_envelopes: Option<BackendFeature<C, dyn ListEnvelopes>>The list envelopes backend feature.
watch_envelopes: Option<BackendFeature<C, dyn WatchEnvelopes>>The watch envelopes backend feature.
add_flags: Option<BackendFeature<C, dyn AddFlags>>The add flags backend feature.
set_flags: Option<BackendFeature<C, dyn SetFlags>>The set flags backend feature.
remove_flags: Option<BackendFeature<C, dyn RemoveFlags>>The remove flags backend feature.
add_message: Option<BackendFeature<C, dyn AddMessage>>The add message backend feature.
send_message: Option<BackendFeature<C, dyn SendMessage>>The send message backend feature.
peek_messages: Option<BackendFeature<C, dyn PeekMessages>>The peek messages backend feature.
get_messages: Option<BackendFeature<C, dyn GetMessages>>The get messages backend feature.
copy_messages: Option<BackendFeature<C, dyn CopyMessages>>The copy messages backend feature.
move_messages: Option<BackendFeature<C, dyn MoveMessages>>The move messages backend feature.
delete_messages: Option<BackendFeature<C, dyn DeleteMessages>>The delete messages backend feature.