Modules
Traits
Functions
- build_
thread_ graph_ all - Build a thread graph from envelopes using In-Reply-To / Message-ID relationships. This is a client-side threading algorithm that works regardless of whether the server supports IMAP THREAD.
- build_
thread_ graph_ for_ id - Build a thread graph filtered to only the thread containing the given envelope ID.