Module dedicated to folders synchronization.
This module contains everything you need to synchronize remote folders with local ones.
Modules
- Module dedicated to email folders synchronization cache.
Structs
- The folder synchronization cache.
- The folder synchronization patch manager.
- The folder synchronization report.
Enums
- The folder synchronization cache hunk.
- The folder synchronization hunk.
- The folder synchronization strategy.
Type Aliases
- Alias for the folder name.
- A folder synchronization cache patch is just a list of folder synchronization cache hunks (changes).
- A folder synchronization patch is just a list of folder synchronization hunks (changes).
- A folder synchronization patches associates a folder with its own patch.
- Alias for the unique set of folder names.