Struct email::Header
[−]
[src]
pub struct Header {
pub name: String,
// some fields omitted
}Represents an RFC 822 Header [unstable]
Fields
name: String
The name of this header
Methods
impl Header[src]
fn new(name: String, value: String) -> Header
Creates a new Header for the given name and value
[unstable]
fn new_with_value<T: ToFoldedHeader>(
name: String,
value: T
) -> ParsingResult<Header>
name: String,
value: T
) -> ParsingResult<Header>
Creates a new Header for the given name and value,
as converted through the ToHeader or ToFoldedHeader trait.
Returns None if the value failed to be converted. [unstable]
fn get_value<T: FromHeader>(&self) -> ParsingResult<T>
Get the value represented by this header, as parsed
into whichever type T
[unstable]