pub trait AnyError:
Error
+ Any
+ Send
+ Sync {
// Required method
fn as_any(&self) -> &dyn Any;
}Expand description
The global, dowcastable any Error trait of the library.
This trait is used instead of [Error] when an error that is not
known at compilation time cannot be placed in a generic due to
object-safe trait constraint. The main use case is for backend
features.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".